@@ -11,25 +11,25 @@ sub new {
 	return bless { }, $class;
 }
 
-# sub error {
-	# my $self = shift;
-	# my $message = shift;
-#
-	# ::diag($message);
-# }
+sub error {
+	my $self = shift;
+	my $message = shift;
 
-# sub warn {
-	# my $self = shift;
-#
-	# ::diag(@_);
-# }
+	::diag($message);
+}
 
-# sub info {
-	# my $self = shift;
-	# my $message = shift;
-#
-	# ::diag($message);
-# }
+sub warn {
+	my $self = shift;
+
+	::diag(@_);
+}
+
+sub info {
+	my $self = shift;
+	my $message = shift;
+
+	::diag($message);
+}
 
 sub trace {
 	my $self = shift;
